@@ -47,14 +47,18 @@ int main (int argc, char *argv[])
 
   CSingleApplicationShared app (argc, argv, "tea unique id 1977");
  
-
   bool single_mode = true;
  
   if (argc > 1)
-     if (strcmp(argv[1], "--m") == 0)
+     if (strcmp (argv[1], "--m") == 0)
         single_mode = false;
 
+  //QStringList l = qApp->arguments();
+//  int size = l.size();
+  //if (size < 2)
+    // return;
 
+/*
   if (single_mode && app.alreadyExists())
      {
       if (argc > 1)
@@ -65,14 +69,26 @@ int main (int argc, char *argv[])
              
       return 0;
      }
-    
+  */
+
+  if (single_mode && app.alreadyExists())
+     {
+      if (argc > 1)
+         for (int i = 1; i < argc; i++)
+             {
+              app.sendMessage (QString (argv[i]));
+             }
+
+      return 0;
+     }
+
 #endif
     
 
   main_window = new CTEA();
 
 #if !defined (NO_SINGLE_APP)
- QObject::connect(&app, SIGNAL(messageAvailable(QStringList)), main_window, SLOT(receiveMessageShared(QStringList)));
+ QObject::connect (&app, SIGNAL(messageAvailable(QStringList)), main_window, SLOT(receiveMessageShared(QStringList)));
 #endif
    
   main_window->show();
