@@ -35,6 +35,7 @@
 #include <QProcess>
 #include <QProxyStyle>
 #include <QToolButton>
+#include <QMainWindow>
 
 #ifdef PRINTER_ENABLE
 #include <QPrinter>
@@ -177,6 +178,9 @@ Variables
   CFMan *fman;
   CImgViewer *img_viewer;
 
+  QTextBrowser md_viewer;
+  QWidget *wnd_about;
+
   CSpellchecker *spellchecker;
   QStringList spellcheckers;
   QString cur_spellchecker;
@@ -384,6 +388,8 @@ Preferences tab :: Interface page UI elements
   QComboBox *cmb_tea_icons;
   QCheckBox *cb_show_linenums;
   QCheckBox *cb_wordwrap;
+  QCheckBox *cb_show_tabs_and_spaces;
+
   QCheckBox *cb_hl_enabled;
   QCheckBox *cb_hl_current_line;
   QCheckBox *cb_hl_brackets;
@@ -691,6 +697,7 @@ Edit menu callbacks
   void ed_copy();
   void ed_paste();
   void ed_cut();
+  void ed_select_all();
   void ed_block_start();
   void ed_block_end();
   void ed_block_copy();
@@ -779,6 +786,8 @@ Fn menu callbacks
   void fn_insert_time();
   void fn_case_up();
   void fn_case_down();
+  void fn_case_inverse();
+
   void fn_case_cap_sentences();
   void fn_sort_casecare();
   void fn_sort_casecareless();
@@ -830,6 +839,13 @@ Fn menu callbacks
   void fn_text_remove_trailing_spaces();
   void fn_text_anagram();
   void fn_text_regexp_match_check();
+
+#if QT_VERSION >= 0x060000
+
+  void fn_math_srt_shift();
+
+#endif
+
   void fn_quotes_to_angle();
   void fn_quotes_curly();
   void fn_quotes_tex_curly();
@@ -944,6 +960,11 @@ View menu callbacks
   void view_stay_on_top();
   void view_darker();
 
+#if QT_VERSION >= 0x051400
+  void view_preview_md();
+#endif
+
+
 /*-----------------------------*/
 
 /*
