@@ -54,6 +54,26 @@
 Do you want to save your changes?</source>
         <translation></translation>
     </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished">Kopieren</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished">Ausschneiden</translation>
+    </message>
+    <message>
+        <source>Paste</source>
+        <translation type="unfinished">Einfügen</translation>
+    </message>
+    <message>
+        <source>Undo</source>
+        <translation type="unfinished">Rückgängig</translation>
+    </message>
+    <message>
+        <source>Redo</source>
+        <translation type="unfinished">Wiederholen</translation>
+    </message>
 </context>
 <context>
     <name>CImgViewer</name>
@@ -84,10 +104,6 @@ Do you want to save your changes?</source>
         <source>famous input field</source>
         <translation></translation>
     </message>
-    <message>
-        <source>All (*);;Text files (*.txt);;Markup files (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++ *.cxx)</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Charset</source>
         <translation>Zeichensatz</translation>
@@ -1827,6 +1843,18 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Preview Markdown</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>All (*);;Text files (*.txt);;Markup files (*.xml *.html *.xhtml *.htm *.md);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++ *.cxx)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select all</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Case inverse</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CTioReadOnly</name>
